@@ -10,7 +10,7 @@
 #define KASTEN_SEARCHCONTROLLERFACTORY_HPP
 
 // lib
-#include <kasten/okteta/oktetakastencontrollers_export.hpp>
+#include "oktetakastencontrollers_export.hpp"
 // Kasten core
 #include <Kasten/AbstractXmlGuiControllerFactory>
 
@@ -22,8 +22,12 @@ class OKTETAKASTENCONTROLLERS_EXPORT SearchControllerFactory : public AbstractXm
 {
 public:
     explicit SearchControllerFactory(QWidget* parentWidget);
+    SearchControllerFactory(const SearchControllerFactory&) = delete;
+
     ~SearchControllerFactory() override;
 
+    SearchControllerFactory& operator=(const SearchControllerFactory&) = delete;
+
 public: // AbstractXmlGuiControllerFactory API
     AbstractXmlGuiController* create(KXMLGUIClient* guiClient) const override;
 
